#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = __importDefault(require("yargs"));
const generate_1 = __importDefault(require("./generate"));
console.log('CLI script started');
(0, yargs_1.default)(process.argv.slice(2))
    .command({
    command: 'generate [typesPath] [outputPath] [supabaseClientPath]',
    aliases: ['g'],
    describe: 'Generate React Query hooks from a types file',
    builder: (yargs) => {
        return yargs
            .positional('typesPath', {
            describe: 'Path to the types file',
            type: 'string',
        })
            .positional('outputPath', {
            describe: 'Path to the output hooks file',
            type: 'string',
        })
            .positional('supabaseClientPath', {
            describe: 'Path to the Supabase client file',
            type: 'string',
        });
    },
    handler: (argv) => {
        console.log('Inside generate command handler');
        (0, generate_1.default)({
            outputPath: argv['outputPath'],
            prettierConfigPath: argv['prettierConfigPath'],
            relativeSupabasePath: argv['relativeSupabasePath'],
            supabaseExportName: argv['supabaseExportName'],
            typesPath: argv['typesPath'],
        });
        console.log('generateHooks function has been called');
    },
})
    .demandCommand(1, 'You need at least one command')
    .strict()
    .help()
    .wrap(72)
    .parse();
console.log('CLI script finished');
